@@ -1,15 +1,17 @@
 source("incl/start.R")
 
+## Setup all strategies including custom once for testing on HPC environments
 print(all_strategies())
 
 message("All HPC strategies:")
+
 strategies <- c("batchtools_lsf", "batchtools_openlava", "batchtools_sge",
                 "batchtools_slurm", "batchtools_torque")
-mprint(strategies)
+mprint(strategies, debug = TRUE)
 
 message("Supported HPC strategies:")
 strategies <- strategies[sapply(strategies, FUN = test_strategy)]
-mprint(strategies)
+mprint(strategies, debug = TRUE)
 
 for (strategy in strategies) {
   plan(strategy)
